#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Apr  5 16:26:13 2020
You can use a contour plot, as follows (based on the examples at
 http://matplotlib.org/examples/pylab_examples/contour_demo.html):
@author: marco
"""

import numpy as np
import matplotlib.pyplot as plt

# Close all already opened plots (if any)
plt.close("all")

# Define the domain
x = np.linspace(-3.0, 1.0, 100)
y = np.linspace(-2.8, 2.8, 100)
X, Y = np.meshgrid(x,y)

# Compute the stability regions
R_Euler = (1+X)**2 + Y**2 - 1
R_Runge = (1+X+0.5*X**2-0.5*Y**2)**2 + (Y+X*Y)**2 - 1
R_Heun = (1+X+0.5*X**2-0.5*Y**2+1/6*X**3-0.5*X*Y**2)**2 + (Y+X*Y+0.5*Y*X**2-1/6*Y**3)**2 - 1

fig = plt.figure(figsize=(10,7))
ax = fig.add_subplot(1, 1, 1)


# Plot
# Change 14.04.2020: N.B.: I changed plt.contour to plt.contourf, and added the
# options levels=[-1,0] at the end
contour_Heun = plt.contourf(X,Y,R_Heun,[0], colors=['#d3574e'], levels=[-1,0])
contour_Runge = plt.contourf(X,Y,R_Runge,[0], colors=['#aab41e'], levels=[-1,0])
contour_Euler = plt.contourf(X,Y,R_Euler,[0], colors=['#3d60a7'], levels=[-1,0])

# Modern colors
#e4ab18

# Move left y-axis and bottim x-axis to centre, passing through (0,0)
ax.spines['left'].set_position('zero')
ax.spines['bottom'].set_position('zero')

# Eliminate upper and right axes
ax.spines['right'].set_color('none')
ax.spines['top'].set_color('none')

# Show ticks in the left and lower axes only
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')

ax.set_yticklabels(['hallo', '-2i', '-i', '0', 'i', '2i'])


plt.axis('equal')
# plt.xlabel('Re(z)')
# plt.ylabel('Im(z)')
plt.title('Stability regions R(z)')

# # Assign labels for the legend
# contour_Euler.collections[0].set_label('Euler')
# contour_Runge.collections[0].set_label('Runge')
# contour_Heun.collections[0].set_label('Heun')


# A workaround to get a nice legend for the stability regions
series_color = []
series_color.append(contour_Euler.collections[0].get_facecolor()[0])
series_color.append(contour_Runge.collections[0].get_facecolor()[0])
series_color.append(contour_Heun.collections[0].get_facecolor()[0])

proxy = [plt.Rectangle((0,0),1,1,fc = pc) for pc in series_color]

plt.legend(proxy, ["Euler","Runge","Heun"], loc='upper left')

plt.grid(linestyle='dashed', color='0.7')

plt.show(block=False)

plt.savefig('Stability_regions.pdf')  
